@@ -1,5 +1,8 @@
 import logging
 from typing import Dict
+from typing import List
+
+from twisted.internet.defer import inlineCallbacks
 
 from peek_abstract_chunked_index.private.client.handlers.ACICacheHandlerABC import (
     ACICacheHandlerABC,
@@ -8,6 +11,9 @@ from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import (
     ACIUpdateDateTupleABC,
 )
 from peek_core_search._private.PluginNames import searchFilt
+from peek_core_search._private.client.controller.SearchIndexCacheController import (
+    SearchIndexCacheController,
+)
 from peek_core_search._private.client.controller.SearchIndexCacheController import (
     clientSearchIndexUpdateFromServerFilt,
 )
@@ -29,3 +35,11 @@ class SearchIndexCacheHandler(ACICacheHandlerABC):
     _updateFromDeviceFilt: Dict = clientSearchIndexWatchUpdateFromDeviceFilt
     _updateFromLogicFilt: Dict = clientSearchIndexUpdateFromServerFilt
     _logger: logging.Logger = logger
+
+    @inlineCallbacks
+    def notifyOfUpdate(self, chunkKeys: List[str]):
+        assert isinstance(
+            self._cacheController, SearchIndexCacheController
+        ), "We expected SearchIndexCacheController"
+        yield self._cacheController.notifyFastIndexOfChunkKeysUpdated(chunkKeys)
+        yield ACICacheHandlerABC.notifyOfUpdate(self, chunkKeys)
