@@ -8,13 +8,13 @@ from vortex.Tuple import Tuple, addTupleType
 
 @addTupleType
 class SearchObjectTypeTuple(Tuple, DeclarativeBase):
-    __tupleType__ = searchTuplePrefix + 'SearchObjectTypeTuple'
-    __tablename__ = 'SearchObjectType'
+    __tupleType__ = searchTuplePrefix + "SearchObjectTypeTuple"
+    __tablename__ = "SearchObjectType"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     name = Column(String, nullable=False)
     title = Column(String, nullable=False)
-    order = Column(Integer, nullable=False, server_default='0')
+    order = Column(Integer, nullable=False, server_default="0")
 
     __table_args__ = (
         Index("idx_ObjType_name", name, unique=True),
