@@ -1,4 +1,4 @@
-import { filter, first, takeUntil } from "rxjs/operators";
+import { filter, first, map, takeUntil } from "rxjs/operators";
 import { Injectable } from "@angular/core";
 import {
     NgLifeCycleEvents,
@@ -13,6 +13,7 @@ import { SearchPropertyTuple, SearchTupleService } from "./_private";
 import { KeywordAutoCompleteTupleAction } from "./_private/tuples/KeywordAutoCompleteTupleAction";
 import { DeviceOfflineCacheService } from "@peek/peek_core_device";
 import { FastKeywordController } from "./_private/fast-keyword-controller";
+import { Observable, zip } from "rxjs";
 
 export interface SearchPropT {
     title: string;
@@ -58,11 +59,34 @@ export class SearchService extends NgLifeCycleEvents {
         super();
         this.fastIndexController = new FastKeywordController(
             searchIndexLoader,
-            searchObjectLoader
+            searchObjectLoader,
+            tupleService,
+            this
         );
         this._loadPropsAndObjs();
     }
 
+    get canSearchOffline$(): Observable<boolean> {
+        return zip(
+            this.searchIndexLoader.isReadyObservable(),
+            this.searchObjectLoader.isReadyObservable()
+        )
+            .pipe(
+                filter(
+                    () =>
+                        this.searchObjectLoader.offlineEnabled &&
+                        this.searchIndexLoader.offlineEnabled
+                )
+            )
+            .pipe(map((values) => true));
+    }
+
+    haveEnoughSearchKeywords(keywordsString: string): boolean {
+        return this.fastIndexController.haveEnoughSearchKeywords(
+            keywordsString
+        );
+    }
+
     /** Get Locations
      *
      * Get the objects with matching keywords from the index..
@@ -73,6 +97,14 @@ export class SearchService extends NgLifeCycleEvents {
         objectTypeId: number | null,
         keywordsString: string
     ): Promise<SearchResultObjectTuple[]> {
+        if (!this.haveEnoughSearchKeywords(keywordsString)) {
+            console.log(
+                `Skipping search for '${keywordsString}'` +
+                    ` as it's too short after excluding keywords`
+            );
+            return [];
+        }
+
         // If we're online
         if (this.vortexStatusService.snapshot.isOnline) {
             return this.getObjectsOnline(
