@@ -23,11 +23,10 @@ import {
 import { EncodedSearchIndexChunkTuple } from "./EncodedSearchIndexChunkTuple";
 import { SearchIndexUpdateDateTuple } from "./SearchIndexUpdateDateTuple";
 import { SearchTupleService } from "../SearchTupleService";
-import { PrivateSearchIndexLoaderStatusTuple } from "./PrivateSearchIndexLoaderStatusTuple";
 
 import {
     DeviceOfflineCacheService,
-    OfflineCacheStatusTuple,
+    OfflineCacheLoaderStatusTuple,
 } from "@peek/peek_core_device";
 
 // ----------------------------------------------------------------------------
@@ -119,7 +118,7 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
     // Saving the cache after each chunk is so expensive, we only do it every 20 or so
     private chunksSavedSinceLastIndexSave = 0;
 
-    private index = new SearchIndexUpdateDateTuple();
+    private index: SearchIndexUpdateDateTuple | null = null;
     private askServerChunks: SearchIndexUpdateDateTuple[] = [];
 
     private _hasLoaded = false;
@@ -127,8 +126,8 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
     private _hasLoadedSubject = new Subject<void>();
     private storage: TupleOfflineStorageService;
 
-    private _statusSubject = new Subject<PrivateSearchIndexLoaderStatusTuple>();
-    private _status = new PrivateSearchIndexLoaderStatusTuple();
+    private _statusSubject = new Subject<OfflineCacheLoaderStatusTuple>();
+    private _status = new OfflineCacheLoaderStatusTuple();
 
     constructor(
         private vortexService: VortexService,
@@ -139,21 +138,39 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
     ) {
         super();
 
+        this._status.pluginName = "peek_core_search";
+        this._status.indexName = "Keyword Index";
+
         this.storage = new TupleOfflineStorageService(
             storageFactory,
             new TupleOfflineStorageNameService(searchIndexCacheStorageName)
         );
 
         this.setupVortexSubscriptions();
-        this._notifyStatus();
 
-        this.deviceCacheControllerService.triggerCachingObservable
+        this.deviceCacheControllerService.offlineModeEnabled$
+            .pipe(takeUntil(this.onDestroyEvent))
+            .pipe(filter((v) => v))
+            .pipe(first())
+            .subscribe(() => {
+                this.initialLoad();
+            });
+
+        this.deviceCacheControllerService.triggerCachingStartObservable
             .pipe(takeUntil(this.onDestroyEvent))
             .pipe(filter((v) => v))
             .subscribe(() => {
-                this.initialLoad();
+                this.askServerForUpdates();
                 this._notifyStatus();
             });
+
+        this.deviceCacheControllerService.triggerCachingResumeObservable
+            .pipe(takeUntil(this.onDestroyEvent))
+
+            .subscribe(() => {
+                this._notifyStatus();
+                this.askServerForNextUpdateChunk();
+            });
     }
 
     isReady(): boolean {
@@ -164,11 +181,11 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
         return this._hasLoadedSubject;
     }
 
-    statusObservable(): Observable<PrivateSearchIndexLoaderStatusTuple> {
+    statusObservable(): Observable<OfflineCacheLoaderStatusTuple> {
         return this._statusSubject;
     }
 
-    status(): PrivateSearchIndexLoaderStatusTuple {
+    status(): OfflineCacheLoaderStatusTuple {
         return this._status;
     }
 
@@ -194,29 +211,26 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
             .then(() => this._getObjectIdsForTokens(tokens, propertyName));
     }
 
-    private _notifyStatus(): void {
-        this._status.cacheForOfflineEnabled =
-            this.deviceCacheControllerService.cachingEnabled;
-        this._status.initialLoadComplete = this.index.initialLoadComplete;
+    private _notifyReady(): void {
+        if (this._hasLoaded) this._hasLoadedSubject.next();
+    }
 
-        this._status.loadProgress = Object.keys(
-            this.index.updateDateByChunkKey
-        ).length;
-        for (let chunk of this.askServerChunks)
-            this._status.loadProgress -= Object.keys(
+    private _notifyStatus(paused: boolean = false): void {
+        this._status.lastCheckDate = new Date();
+        this._status.paused = paused;
+        this._status.initialFullLoadComplete = this.index.initialLoadComplete;
+
+        this._status.loadingQueueCount = 0;
+        for (let chunk of this.askServerChunks) {
+            this._status.loadingQueueCount += Object.keys(
                 chunk.updateDateByChunkKey
             ).length;
+        }
 
         this._statusSubject.next(this._status);
-
-        const status = new OfflineCacheStatusTuple();
-        status.pluginName = "peek_core_search";
-        status.indexName = "Keyword Index";
-        status.loadingQueueCount = this._status.loadProgress;
-        status.totalLoadedCount = this._status.loadTotal;
-        status.lastCheckDate = new Date();
-        status.initialFullLoadComplete = this._status.initialLoadComplete;
-        this.deviceCacheControllerService.updateCachingStatus(status);
+        this.deviceCacheControllerService.updateLoaderCachingStatus(
+            this._status
+        );
     }
 
     /** Initial load
@@ -228,20 +242,19 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
             .loadTuples(new UpdateDateTupleSelector())
             .then((tuplesAny: any[]) => {
                 let tuples: SearchIndexUpdateDateTuple[] = tuplesAny;
-                if (tuples.length != 0) {
+                if (tuples.length === 0) {
+                    this.index = new SearchIndexUpdateDateTuple();
+                } else {
                     this.index = tuples[0];
 
                     if (this.index.initialLoadComplete) {
                         this._hasLoaded = true;
-                        this._hasLoadedSubject.next();
+                        this._notifyReady();
                     }
                 }
 
-                this.askServerForUpdates();
                 this._notifyStatus();
             });
-
-        this._notifyStatus();
     }
 
     private setupVortexSubscriptions(): void {
@@ -255,12 +268,6 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
             .subscribe((payloadEnvelope: PayloadEnvelope) => {
                 this.processChunksFromServer(payloadEnvelope);
             });
-
-        // If the vortex service comes back online, update the watch grids.
-        this.vortexStatusService.isOnline
-            .pipe(filter((isOnline) => isOnline == true))
-            .pipe(takeUntil(this.onDestroyEvent))
-            .subscribe(() => this.askServerForUpdates());
     }
 
     private areWeTalkingToTheServer(): boolean {
@@ -292,7 +299,7 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
                 let keys = Object.keys(serverIndex.updateDateByChunkKey);
                 let keysNeedingUpdate: string[] = [];
 
-                this._status.loadTotal = keys.length;
+                this._status.totalLoadedCount = keys.length;
 
                 // Tuples is an array of strings
                 for (let chunkKey of keys) {
@@ -341,7 +348,7 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
 
         this.askServerForNextUpdateChunk();
 
-        this._status.lastCheck = new Date();
+        this._status.lastCheckDate = new Date();
         this._notifyStatus();
     }
 
@@ -350,22 +357,21 @@ export class PrivateSearchIndexLoaderService extends NgLifeCycleEvents {
 
         if (this.askServerChunks.length == 0) return;
 
-        this.deviceCacheControllerService //
-            .waitForGarbageCollector()
-            .then(() => {
-                let indexChunk: SearchIndexUpdateDateTuple =
-                    this.askServerChunks.pop();
-                let filt = extend(
-                    {},
-                    clientSearchIndexWatchUpdateFromDeviceFilt
-                );
-                filt[cacheAll] = true;
-                let pl = new Payload(filt, [indexChunk]);
-                this.vortexService.sendPayload(pl);
+        if (this.deviceCacheControllerService.isOfflineCachingPaused) {
+            this.saveChunkCacheIndex(true) //
+                .catch((e) => console.log(`ERROR saveChunkCacheIndex: ${e}`));
+            this._notifyStatus(true);
+            return;
+        }
 
-                this._status.lastCheck = new Date();
-                this._notifyStatus();
-            });
+        let indexChunk: SearchIndexUpdateDateTuple = this.askServerChunks.pop();
+        let filt = extend({}, clientSearchIndexWatchUpdateFromDeviceFilt);
+        filt[cacheAll] = true;
+        let pl = new Payload(filt, [indexChunk]);
+        this.vortexService.sendPayload(pl);
+
+        this._status.lastCheckDate = new Date();
+        this._notifyStatus();
     }
 
     /** Process SearchIndexes From Server
